@@ -1,3 +1,3 @@
-from .framework import *
+from .eeframework import *
 from .core import *
 from .msg import *
\ No newline at end of file
